"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileService__Consumer = exports.FileService__Producer = exports.FileType = void 0;
const tiny_typed_emitter_1 = require("tiny-typed-emitter");
const soa_client_1 = require("@cross-lab-project/soa-client");
const soa_client_2 = require("@cross-lab-project/soa-client");
const ServiceType = "goldi/file";
function checkConfig(config) {
    if (config.serviceType !== ServiceType) {
        //throw Error("Service Configuration needs to be for FileService type");
    }
}
var FileType;
(function (FileType) {
    FileType[FileType["Hex"] = 0] = "Hex";
    FileType[FileType["Elf"] = 1] = "Elf";
})(FileType = exports.FileType || (exports.FileType = {}));
class FileService extends tiny_typed_emitter_1.TypedEmitter {
    constructor(serviceId) {
        super();
        this.serviceType = ServiceType;
        this.serviceId = serviceId;
    }
    getMeta() {
        return {
            serviceId: this.serviceId,
            serviceType: ServiceType,
            serviceDirection: this.serviceDirection,
        };
    }
}
/**
 * - maybe it would also suffice to just use the Prosumer ServiceDirection
 * - maybe move sendFile function to an interface
 */
class FileService__Producer extends FileService {
    constructor() {
        super(...arguments);
        this.serviceDirection = soa_client_1.Producer;
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new soa_client_2.DataChannel();
        connection.transmit(serviceConfig, "data", channel);
        this.channel = channel;
    }
    async sendFile(file) {
        if (this.channel !== undefined) {
            await this.channel.ready();
            this.channel.send(JSON.stringify({ fileType: 'hex', length: file.content.length }));
            this.channel.send(file.content);
        }
    }
}
exports.FileService__Producer = FileService__Producer;
class FileService__Consumer extends FileService {
    constructor() {
        super(...arguments);
        this.serviceDirection = soa_client_1.Consumer;
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new soa_client_2.DataChannel();
        channel.ondata = this.handleData.bind(this);
        connection.receive(serviceConfig, "data", channel);
    }
    handleData(data) {
        if (typeof data === "string") {
            this.header = JSON.parse(data);
        }
        else {
            console.log(this.header);
            throw Error("FileService__Consumer not implemented");
        }
    }
}
exports.FileService__Consumer = FileService__Consumer;
//# sourceMappingURL=file.js.map