import { TypedEmitter } from "tiny-typed-emitter";
import { Producer, Consumer } from "@cross-lab-project/soa-client";
import { DataChannel } from "@cross-lab-project/soa-client";
const ServiceType = "goldi/file";
function checkConfig(config) {
    if (config.serviceType !== ServiceType) {
        //throw Error("Service Configuration needs to be for FileService type");
    }
}
export var FileType;
(function (FileType) {
    FileType[FileType["Hex"] = 0] = "Hex";
    FileType[FileType["Elf"] = 1] = "Elf";
})(FileType || (FileType = {}));
class FileService extends TypedEmitter {
    constructor(serviceId) {
        super();
        this.serviceType = ServiceType;
        this.serviceId = serviceId;
    }
    getMeta() {
        return {
            serviceId: this.serviceId,
            serviceType: ServiceType,
            serviceDirection: this.serviceDirection,
        };
    }
}
/**
 * - maybe it would also suffice to just use the Prosumer ServiceDirection
 * - maybe move sendFile function to an interface
 */
export class FileService__Producer extends FileService {
    constructor() {
        super(...arguments);
        this.serviceDirection = Producer;
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new DataChannel();
        connection.transmit(serviceConfig, "data", channel);
        this.channel = channel;
    }
    async sendFile(file) {
        if (this.channel !== undefined) {
            await this.channel.ready();
            this.channel.send(JSON.stringify({ fileType: 'hex', length: file.content.length }));
            this.channel.send(file.content);
        }
    }
}
export class FileService__Consumer extends FileService {
    constructor() {
        super(...arguments);
        this.serviceDirection = Consumer;
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new DataChannel();
        channel.ondata = this.handleData.bind(this);
        connection.receive(serviceConfig, "data", channel);
    }
    handleData(data) {
        if (typeof data === "string") {
            this.header = JSON.parse(data);
        }
        else {
            console.log(this.header);
            throw Error("FileService__Consumer not implemented");
        }
    }
}
//# sourceMappingURL=file.js.map